==> jc-1.4.0.tar.gz: polyglot/visit/FlowGraph__24EdgeKey.h <==
// public class polyglot.visit.FlowGraph$EdgeKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1c159fd356ae4105 polyglot_visit_FlowGraph__24EdgeKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24EdgeKey_H_
#define _JC_polyglot_visit_FlowGraph__24EdgeKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	_jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$refs	_jc_polyglot_visit_FlowGraph__24EdgeKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs	_jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	_jc_polyglot_visit_FlowGraph__24EdgeKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtable	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24EdgeKey$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_FlowGraph__24EdgeKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_visit_FlowGraph__24EdgeKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24EdgeKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *);
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	polyglot_visit_FlowGraph__24EdgeKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs {
	struct _jc_java_lang_Object$object	*o;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$refs {
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24EdgeKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object {
	_jc_polyglot_visit_FlowGraph__24EdgeKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype _jc_polyglot_visit_FlowGraph__24EdgeKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24EdgeKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24EdgeKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24EdgeKey_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlowGraph__24EdgeKey.h <==
// public class polyglot.visit.FlowGraph$EdgeKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1c159fd356ae4105 polyglot_visit_FlowGraph__24EdgeKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24EdgeKey_H_
#define _JC_polyglot_visit_FlowGraph__24EdgeKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	_jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$refs	_jc_polyglot_visit_FlowGraph__24EdgeKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs	_jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	_jc_polyglot_visit_FlowGraph__24EdgeKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtable	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24EdgeKey$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_FlowGraph__24EdgeKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_visit_FlowGraph__24EdgeKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24EdgeKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_visit_FlowGraph__24EdgeKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	polyglot_visit_FlowGraph__24EdgeKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs {
	struct _jc_java_lang_Object$object	*o;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$refs {
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24EdgeKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object {
	_jc_polyglot_visit_FlowGraph__24EdgeKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24EdgeKey$vtype _jc_polyglot_visit_FlowGraph__24EdgeKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24EdgeKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24EdgeKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24EdgeKey_H_ */
